==> indigitall_flutter_plugin-0.5.0.tar.gz: lib/core/models/CoreAction.dart <==
import 'dart:convert';

class CoreAction {
  /// String field name destroy
  static const String _DESTROY = "destroy";

  /// String field name topics
  static const String _TOPICS = "topics";

  /// String field name type
  static const String _TYPE = "type";

  /// String field name type app
  static const String TYPE_APP = "app";

  /// String field name type url
  static const String TYPE_URL = "url";

  /// String field name type call
  static const String TYPE_CALL = "call";

  /// String field name type market
  static const String TYPE_MARKET = "market";

  /// String field name type share
  static const String TYPE_SHARE = "share";

  /// String field name type no action
  static const String TYPE_NO_ACTION = "no_action";

  /// String field name type wallet
  static const String TYPE_WALLET = "wallet";

  /// Action description string
  static const String ACTION = "action";

  /// action type boolean destroy
  bool destroy = true;

  /// action type list of topics
  List<String>? topics;

  /// action type
  Type? type;

  /// action type app
  String? app;

  /// action type url
  String? url;

  /// action type call
  String? call;

  /// action type market
  String? market;

  /// action type share
  String? share;

  /// action type no action
  String? no_action;

  /// action type wallet
  String? wallet;

  /// Constructor of CoreAction
  CoreAction(Map map) {
    map.forEach((key, value) {
      switch (key) {
        case _DESTROY:
          destroy = value.toString() == "true";
          break;
        case _TOPICS:
          topics = json.decode(value.toString());
          break;
        case _TYPE:
          type = getType(value.toString());
          break;
        case TYPE_APP:
          app = value.toString();
          break;
        case TYPE_URL:
          url = value.toString();
          break;
        case TYPE_CALL:
          call = value.toString();
          break;
        case TYPE_MARKET:
          market = value.toString();
          break;
        case TYPE_SHARE:
          share = value.toString();
          break;
        case TYPE_NO_ACTION:
          no_action = value.toString();
          break;
        case TYPE_WALLET:
          wallet = value.toString();
          break;
      }
    });
  }

  /// Convertion Model [CoreAction] to Map
  Map toMap() {
    Map map = Map();
    if (topics != null) map[_TOPICS] = topics;
    if (type != null) map[_TYPE] = type.toString();
    if (app != null) map[TYPE_APP] = app;
    if (url != null) map[TYPE_URL] = url;
    if (call != null) map[TYPE_CALL] = call;
    if (market != null) map[TYPE_MARKET] = market;
    if (share != null) map[TYPE_SHARE] = share;
    if (no_action != null) map[TYPE_NO_ACTION] = no_action;
    if (wallet != null) map[TYPE_WALLET] = wallet;
    return map;
  }
}

/// enum with action types
enum Type { APP, URL, CALL, MARKET, SHARE, NO_ACTION, WALLET }

/// get Type String
Type getType(String type) {
  Type value = Type.APP;
  switch (type) {
    case CoreAction.TYPE_APP:
      value = Type.APP;
      break;
    case CoreAction.TYPE_URL:
      value = Type.URL;
      break;
    case CoreAction.TYPE_CALL:
      value = Type.CALL;
      break;
    case CoreAction.TYPE_MARKET:
      value = Type.MARKET;
      break;
    case CoreAction.TYPE_SHARE:
      value = Type.SHARE;
      break;
    case CoreAction.TYPE_NO_ACTION:
      value = Type.NO_ACTION;
      break;
    case CoreAction.TYPE_WALLET:
      value = Type.WALLET;
      break;
  }
  return value;
}

==> indigitall_flutter_plugin-2.0.2.tar.gz: lib/core/models/CoreAction.dart <==
import 'dart:convert';

class CoreAction {
  /// String field name destroy
  static const String _DESTROY = "destroy";

  /// String field name topics
  static const String _TOPICS = "topics";

  /// String field name type
  static const String _TYPE = "type";

  /// String field name type app
  static const String TYPE_APP = "app";

  /// String field name type url
  static const String TYPE_URL = "url";

  /// String field name type call
  static const String TYPE_CALL = "call";

  /// String field name type market
  static const String TYPE_MARKET = "market";

  /// String field name type share
  static const String TYPE_SHARE = "share";

  /// String field name type no action
  static const String TYPE_NO_ACTION = "no_action";

  /// String field name type wallet
  static const String TYPE_WALLET = "wallet";

  /// Action description string
  static const String ACTION = "action";

  /// action type boolean destroy
  bool destroy = true;

  /// action type list of topics
  List<String>? topics;

  /// action type
  Type? type;

  /// action type app
  String? app;

  /// action type url
  String? url;

  /// action type call
  String? call;

  /// action type market
  String? market;

  /// action type share
  String? share;

  /// action type no action
  String? noAction;

  /// action type wallet
  String? wallet;

  /// Constructor of CoreAction
  CoreAction(Map map) {
    map.forEach((key, value) {
      switch (key) {
        case _DESTROY:
          destroy = value.toString() == "true";
          break;
        case _TOPICS:
          topics = json.decode(value.toString());
          break;
        case _TYPE:
          type = getType(value.toString());
          break;
        case TYPE_APP:
          app = value.toString();
          break;
        case TYPE_URL:
          url = value.toString();
          break;
        case TYPE_CALL:
          call = value.toString();
          break;
        case TYPE_MARKET:
          market = value.toString();
          break;
        case TYPE_SHARE:
          share = value.toString();
          break;
        case TYPE_NO_ACTION:
          noAction = value.toString();
          break;
        case TYPE_WALLET:
          wallet = value.toString();
          break;
      }
    });
  }

  /// Convertion Model [CoreAction] to Map
  Map toMap() {
    Map map = Map();
    if (topics != null) map[_TOPICS] = topics;
    if (type != null) map[_TYPE] = type.toString();
    if (app != null) map[TYPE_APP] = app;
    if (url != null) map[TYPE_URL] = url;
    if (call != null) map[TYPE_CALL] = call;
    if (market != null) map[TYPE_MARKET] = market;
    if (share != null) map[TYPE_SHARE] = share;
    if (noAction != null) map[TYPE_NO_ACTION] = noAction;
    if (wallet != null) map[TYPE_WALLET] = wallet;
    return map;
  }
}

/// enum with action types
enum Type { APP, URL, CALL, MARKET, SHARE, NO_ACTION, WALLET }

/// get Type String
Type getType(String type) {
  Type value = Type.APP;
  switch (type) {
    case CoreAction.TYPE_APP:
      value = Type.APP;
      break;
    case CoreAction.TYPE_URL:
      value = Type.URL;
      break;
    case CoreAction.TYPE_CALL:
      value = Type.CALL;
      break;
    case CoreAction.TYPE_MARKET:
      value = Type.MARKET;
      break;
    case CoreAction.TYPE_SHARE:
      value = Type.SHARE;
      break;
    case CoreAction.TYPE_NO_ACTION:
      value = Type.NO_ACTION;
      break;
    case CoreAction.TYPE_WALLET:
      value = Type.WALLET;
      break;
  }
  return value;
}
